/*
    SpecRunner - Acceptance Test Driven Development Tool
    Copyright (C) 2011-2013  Thiago Santos

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>
 */
package org.specrunner.impl.pipes.shutdown;

import org.specrunner.SpecRunnerServices.ShutDown;
import org.specrunner.pipeline.AbortException;
import org.specrunner.pipeline.IChannel;
import org.specrunner.pipeline.IPipe;
import org.specrunner.pipeline.PipelineException;
import org.specrunner.reuse.IReusable;
import org.specrunner.reuse.IReuseManager;

/**
 * Finalize all reusable resources.
 * 
 * @author Thiago Santos
 * 
 */
public class PipeReusable implements IPipe {

    @Override
    public boolean check(IChannel channel) throws AbortException {
        return true;
    }

    @Override
    public IChannel process(IChannel channel) throws AbortException, PipelineException {
        IReuseManager rm = ShutDown.recover(channel).lookup(IReuseManager.class);
        for (IReusable<?> r : rm.values()) {
            r.release();
            rm.remove(r);
        }
        return channel;
    }
}
